summary refs log tree commit diff
path: root/keyboards/handwired/6macro
diff options
context:
space:
mode:
authorJoel Challis <git@zvecr.com>2022-05-15 20:26:27 +0100
committerGitHub <noreply@github.com>2022-05-15 20:26:27 +0100
commitb7771ec25b96f2b88a7fa4201081e10ca6fbb9d4 (patch)
tree407a374842244534259c36e94c996be7490cea0a /keyboards/handwired/6macro
parent4a8bd7b9a523601911ba467588b2a6a0aa693db6 (diff)
RESET -> QK_BOOT default keymaps (#17037)
Diffstat (limited to 'keyboards/handwired/6macro')
-rw-r--r--keyboards/handwired/6macro/keymaps/default/keymap.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/keyboards/handwired/6macro/keymaps/default/keymap.c b/keyboards/handwired/6macro/keymaps/default/keymap.c
index 1c6b91a7d3..26c6f84dcd 100644
--- a/keyboards/handwired/6macro/keymaps/default/keymap.c
+++ b/keyboards/handwired/6macro/keymaps/default/keymap.c
@@ -33,7 +33,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
   * ,-----------------------.
   * |RGB_TOG|RGBMOD+|       |
   * |-------+-------+-------|
   * |RGBHUE+|RGBBRI+|Spec FN|   Hold along with previous to access special funtions (RESET)
   * `-------+-------+-------'
   */
   [1] = LAYOUT(
@@ -43,13 +43,13 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
 
   /* LAYER 2
   * ,-----------------------.
-  * | RESET |RGBMOD-|       |
+  * | QK_BOOT |RGBMOD-|       |
   * |-------+-------+-------|
   * |RGBHUE-|RGBBRI-|       |
   * `-------+-------+-------'
   */
   [2] = LAYOUT(
-    RESET, RGB_RMOD, KC_NO,
+    QK_BOOT, RGB_RMOD, KC_NO,
     RGB_HUD, RGB_VAD, KC_TRNS
   )
@@ -33,7 +33,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
   * |RGB_TOG|RGBMOD+|       |
   * |-------+-------+-------|
-  * |RGBHUE+|RGBBRI+|Spec FN|   Hold along with previous to access special funtions (RESET)
+  * |RGBHUE+|RGBBRI+|Spec FN|   Hold along with previous to access special funtions (QK_BOOT)
   * `-------+-------+-------'
   */